@@ -35,7 +35,7 @@
 #endif
 
 /* Define the canonical host system type as a string constant */
-#define CANONICAL_HOST_TYPE "sparc64-OpenBSD"
+#define CANONICAL_HOST_TYPE "i386-OpenBSD"
 
 /* Define if char is unsigned on the C compiler */
 /* #undef C_CHAR_UNSIGNED */
@@ -47,7 +47,7 @@
 #define DCMTK_PREFIX "/usr/local"
 
 /* Define the default data dictionary path for the dcmdata library package */
-#define DCM_DICT_DEFAULT_PATH "/usr/local/share/dcmtk-3.6.9/dicom.dic"
+#define DCM_DICT_DEFAULT_PATH "/usr/local/share/dcmtk-3.7.0/dicom.dic"
 
 /* Define the type of standard dictionary that we want to use:
    0 - Do not load any default dictionary on startup
@@ -62,17 +62,14 @@
 /* Define the environment variable path separator */
 #define ENVIRONMENT_PATH_SEPARATOR ':'
 
-/* Define to 1 if you have the `access' function. */
-#define HAVE_ACCESS 1
-
 /* Define to 1 if you have the <alloca.h> header file. */
 /* #undef HAVE_ALLOCA_H */
 
 /* Define to 1 if you have the <arpa/inet.h> header file. */
 #define HAVE_ARPA_INET_H 1
 
-/* Define to 1 if you have the `bcmp' function. */
-#define HAVE_BCMP 1
+/* Define to 1 if you have the <cstdint> header file. */
+#define HAVE_CSTDINT 1
 
 /* Define to 1 if you have the `cuserid' function. */
 /* #undef HAVE_CUSERID */
@@ -80,9 +77,6 @@
 /* Define to 1 if you have the `fgetln' function. */
 #define HAVE_FGETLN 1
 
-/* Define if your system has a declaration for fp_except_t in ieeefp.h */
-/* #undef HAVE_DECLARATION_FP_EXCEPT_T */
-
 /* Define to 1 if you have the <dirent.h> header file, and it defines `DIR'.*/
 #define HAVE_DIRENT_H 1
 
@@ -92,12 +86,6 @@
 /* Define to 1 if <errno.h> defined ENAMETOOLONG. */
 #define HAVE_ENAMETOOLONG 1
 
-/* Define to 1 if you have the <fcntl.h> header file. */
-#define HAVE_FCNTL_H 1
-
-/* Define to 1 if you have the `finite' function. */
-#define HAVE_FINITE 1
-
 /* Define to 1 if you have the `flock' function. */
 #define HAVE_FLOCK 1
 
@@ -140,15 +128,9 @@
 /* Define to 1 if you have the `getlogin_r' function. */
 #define HAVE_GETLOGIN_R 1
 
-/* Define to 1 if you have the `getpid' function. */
-#define HAVE_GETPID 1
-
 /* Define to 1 if you have the `getpwnam' function. */
 #define HAVE_GETPWNAM 1
 
-/* Define to 1 if you have the `getrusage' function. */
-#define HAVE_GETRUSAGE 1
-
 /* Define to 1 if you have the `gettimeofday' function. */
 #define HAVE_GETTIMEOFDAY 1
 
@@ -164,41 +146,18 @@
 /* Define to 1 if you have the <ieeefp.h> header file. */
 #define HAVE_IEEEFP_H 1
 
-/* Define to 1 if you have the `index' function. */
-#define HAVE_INDEX 1
-
-/* Define if your system declares argument 3 of accept() as int * instead of
-   size_t * or socklen_t * */
-/* #undef HAVE_INTP_ACCEPT */
-
-/* Define if your system declares argument 5 of getsockopt() as int * instead
-   of size_t * or socklen_t */
-/* #undef HAVE_INTP_GETSOCKOPT */
-
 /* Define to 1 if you have the <io.h> header file. */
 /* #undef HAVE_IO_H */
 
-/* Define to 1 if you have the `itoa' function. */
-/* #undef HAVE_ITOA */
-
 /* Define to 1 if you have the <langinfo.h> header file. */
 #define HAVE_LANGINFO_H 1
 
 /* Define to 1 if you have the <libc.h> header file. */
 /* #undef HAVE_LIBC_H */
 
-/* Define to 1 if you have the `nsl' library (-lnsl). */
-/* #undef HAVE_LIBNSL */
-
 /* Define to 1 if the <libpng/png.h> header shall be used instead of <png.h>. */
 /* #undef HAVE_LIBPNG_PNG_H */
 
-/* Define to 1 if you have the `socket' library (-lsocket). */
-/* #undef HAVE_LIBSOCKET */
-
-/* Define to 1 if you have the `listen' function. */
-#define HAVE_LISTEN 1
-
 /* Define to 1 if you have the `localtime_r' function. */
 #define HAVE_LOCALTIME_R 1
 
@@ -211,15 +170,9 @@
 /* Define to 1 if you have the `malloc_debug' function. */
 /* #undef HAVE_MALLOC_DEBUG */
 
-/* Define to 1 if you have the <malloc.h> header file. */
-/* #undef HAVE_MALLOC_H */
-
 /* Define to 1 if you have the `mkstemp' function. */
 #define HAVE_MKSTEMP 1
 
-/* Define to 1 if you have the `mktemp' function. */
-#define HAVE_MKTEMP 1
-
 /* Define to 1 if you have the <mqueue.h> header file. */
 /* #undef HAVE_MQUEUE_H */
 
@@ -241,12 +194,6 @@
 /* Define to 1 if you have readdir_r */
 #define HAVE_READDIR_R 1
 
-/* Define if your system has a prototype for feenableexcept in fenv.h */
-/* #undef HAVE_PROTOTYPE_FEENABLEEXCEPT */
-
-/* Define if your system has a prototype for finite in math.h */
-#define HAVE_PROTOTYPE_FINITE 1
-
 /* Define to 1 if your has a prototype for `TryAcquireSRWLockShared' in windows.h (Win32 only). */
 /* #undef HAVE_PROTOTYPE_TRYACQUIRESRWLOCKSHARED */
 
@@ -269,26 +216,6 @@
    unistd.h */
 #define HAVE_PROTOTYPE_GETTIMEOFDAY 1
 
-/* Define if your system has a prototype for std::isinf in cmath */
-#define HAVE_PROTOTYPE_STD__ISINF 1
-
-/* Define if your system has a prototype for std::isnan in cmath */
-#define HAVE_PROTOTYPE_STD__ISNAN 1
-
-/* Define if your system has a prototype for fpclassf in math.h */
-/* #undef HAVE_PROTOTYPE__FPCLASSF */
-
-/* Define if your system has a prototype for mkstemp in libc.h unistd.h
-   stdlib.h */
-#define HAVE_PROTOTYPE_MKSTEMP 1
-
-/* Define if your system has a prototype for mktemp in libc.h unistd.h
-   stdlib.h */
-#define HAVE_PROTOTYPE_MKTEMP 1
-
-/* Define if your system has a prototype for std::vfprintf in stdarg.h */
-#define HAVE_PROTOTYPE_STD__VFPRINTF 1
-
 /* Define if your system has a prototype for std::vsnprintf in stdio.h */
 #define HAVE_PROTOTYPE_STD__VSNPRINTF 1
 
@@ -319,9 +246,6 @@
 /* Define if your system has a prototype for _stricmp in string.h */
 /* #undef HAVE_PROTOTYPE__STRICMP */
 
-/* Define if your system has a prototype for nanosleep in time.h */
-#define HAVE_PROTOTYPE_NANOSLEEP 1
-
 /* Define to 1 if you have the <pthread.h> header file. */
 #define HAVE_PTHREAD_H 1
 
@@ -331,9 +255,6 @@
 /* Define to 1 if you have the <pwd.h> header file. */
 #define HAVE_PWD_H 1
 
-/* Define to 1 if you have the `rindex' function. */
-#define HAVE_RINDEX 1
-
 /* Define to 1 if you have the <semaphore.h> header file. */
 #define HAVE_SEMAPHORE_H 1
 
@@ -343,21 +264,6 @@
 /* Define to 1 if you have the `sleep' function. */
 #define HAVE_SLEEP 1
 
-/* Define to 1 if you have the `stat' function. */
-#define HAVE_STAT 1
-
-/* Define to 1 if you have the <stdint.h> header file. */
-#define HAVE_STDINT_H 1
-
-/* Define to 1 if you have the C++11 <system_error> header file. */
-#define HAVE_SYSTEM_ERROR 1
-
-/* Define to 1 if you have the <cstdint> header file. */
-#define HAVE_CSTDINT 1
-
-/* Define to 1 if you have the `strdup' function. */
-#define HAVE_STRDUP 1
-
 /* Define to 1 if `strerror_r' returns a char*. */
 /* #undef HAVE_CHARP_STRERROR_R */
 
@@ -397,9 +303,6 @@
 /* Define to 1 if you have the <sys/dir.h> header file, and it defines `DIR'.*/
 #define HAVE_SYS_DIR_H 1
 
-/* Define to 1 if you have the <sys/errno.h> header file. */
-#define HAVE_SYS_ERRNO_H 1
-
 /* Define to 1 if you have the <sys/file.h> header file. */
 #define HAVE_SYS_FILE_H 1
 
@@ -424,9 +327,6 @@
 /* Define to 1 if you have the <sys/socket.h> header file. */
 #define HAVE_SYS_SOCKET_H 1
 
-/* Define to 1 if you have the <sys/stat.h> header file. */
-#define HAVE_SYS_STAT_H 1
-
 /* Define to 1 if you have the <sys/syscall.h> header file. */
 #define HAVE_SYS_SYSCALL_H 1
 
@@ -436,9 +336,6 @@
 /* Define to 1 if you have the <sys/time.h> header file. */
 #define HAVE_SYS_TIME_H 1
 
-/* Define to 1 if you have the <sys/types.h> header file. */
-#define HAVE_SYS_TYPES_H 1
-
 /* Define to 1 if you have the <sys/un.h> header file. */
 #define HAVE_SYS_UN_H 1
 
@@ -454,9 +351,6 @@
 /* Define to 1 if you have the <thread.h> header file. */
 /* #undef HAVE_THREAD_H */
 
-/* Define to 1 if you have the C++11 <tuple> header file. */
-#define HAVE_TUPLE 1
-
 /* Define to 1 if you have the C++11 <type_traits> header file. */
 #define HAVE_TYPE_TRAITS 1
 
@@ -481,9 +375,6 @@
 /* Define to 1 if you have the `vfprintf_s' function. */
 /* #undef HAVE_VFPRINTF_S */
 
-/* Define to 1 if you have the `vsnprintf' function. */
-#define HAVE_VSNPRINTF 1
-
 /* Define to 1 if you have the `vsprintf_s' function. */
 /* #undef HAVE_VSPRINTF_S */
 
@@ -521,25 +412,25 @@
 #define PACKAGE_STRING ""
 
 /* Define to the default configuration directory (used by some applications) */
-#define DEFAULT_CONFIGURATION_DIR "/usr/local/share/examples/dcmtk-3.6.9/"
+#define DEFAULT_CONFIGURATION_DIR "/usr/local/share/examples/dcmtk-3.7.0/"
 
 /* Define to the default support data directory (used by some applications) */
-#define DEFAULT_SUPPORT_DATA_DIR "/usr/local/share/dcmtk-3.6.9/"
+#define DEFAULT_SUPPORT_DATA_DIR "/usr/local/share/dcmtk-3.7.0/"
 
 /* Define to the one symbol short name of this package. */
 /* #undef PACKAGE_TARNAME */
 
 /* Define to the date of this package. */
-#define PACKAGE_DATE "2024-12-11"
+#define PACKAGE_DATE "2025-12-15"
 
 /* Define to the version of this package. */
-#define PACKAGE_VERSION "3.6.9"
+#define PACKAGE_VERSION "3.7.0"
 
 /* Define to the version suffix of this package. */
 #define PACKAGE_VERSION_SUFFIX ""
 
 /* Define to the version number of this package. */
-#define PACKAGE_VERSION_NUMBER 369
+#define PACKAGE_VERSION_NUMBER 370
 
 /* Define path separator */
 #define PATH_SEPARATOR '/'
@@ -551,23 +442,14 @@
 /* Select LFS mode (defined above) that shall be used or don't define it */
 #define DCMTK_ENABLE_LFS DCMTK_LFS
 
-/* The size of a `double', as computed by sizeof. */
-#define SIZEOF_DOUBLE 8
-
-/* The size of a `float', as computed by sizeof. */
-#define SIZEOF_FLOAT 4
-
 /* The size of a `int', as computed by sizeof. */
 #define SIZEOF_INT 4
 
 /* The size of a `long', as computed by sizeof. */
-#define SIZEOF_LONG 8
-
-/* The size of a `short', as computed by sizeof. */
-#define SIZEOF_SHORT 2
+#define SIZEOF_LONG 4
 
 /* The size of a `void *', as computed by sizeof. */
-#define SIZEOF_VOID_P 8
+#define SIZEOF_VOID_P 4
 
 /* The size of a `fpos_t', as computed by sizeof. */
 #define SIZEOF_FPOS_T 8
@@ -617,7 +499,7 @@
 /* #undef ENABLE_PRIVATE_TAGS */
 
 /* Define if we are compiling with sndfile support. */
-#define WITH_SNDFILE
+/* #undef WITH_SNDFILE */
 
 /* Define if we are compiling with libwrap (TCP wrapper) support */
 /* #undef WITH_TCPWRAPPER */
@@ -654,27 +536,6 @@
 #endif
 #endif
 
-/* Set typedefs as needed for JasPer library */
-/* #undef HAVE_UCHAR_TYPEDEF */
-#ifndef HAVE_UCHAR_TYPEDEF
-typedef unsigned char uchar;
-#endif
-
-#define HAVE_USHORT_TYPEDEF
-#ifndef HAVE_USHORT_TYPEDEF
-typedef unsigned short ushort;
-#endif
-
-#define HAVE_UINT_TYPEDEF
-#ifndef HAVE_UINT_TYPEDEF
-typedef unsigned int uint;
-#endif
-
-#define HAVE_ULONG_TYPEDEF
-#ifndef HAVE_ULONG_TYPEDEF
-typedef unsigned long ulong;
-#endif
-
 #define HAVE_LONG_LONG
 #define HAVE_UNSIGNED_LONG_LONG
 
@@ -682,63 +543,39 @@ typedef unsigned long ulong;
 #define HAVE_UINT64_T 1
 
  /* Additional settings for Borland C++ Builder */
-#ifdef __BORLANDC__
+
+#if defined(__BORLANDC__) && (!defined(_WIN64) || !defined(__MINGW64__))
+#define HAVE_CLASSIC_BORLAND_COMPILER
+#endif
+
+#ifdef HAVE_CLASSIC_BORLAND_COMPILER
+#define _MSC_VER 1200       /* Treat Borland C++ 5.5 as MSVC6. */
 #define _stricmp stricmp    /* _stricmp in MSVC is stricmp in Borland C++ */
 #define _strnicmp strnicmp  /* _strnicmp in MSVC is strnicmp in Borland C++ */
-    #pragma warn -8027      /* disable Warning W8027 "functions containing while are not expanded inline" */
-    #pragma warn -8004      /* disable Warning W8004 "variable is assigned a value that is never used" */
-    #pragma warn -8012      /* disable Warning W8012 "comparing signed and unsigned values" */
+#pragma warn -8027          /* disable Warning W8027 "functions containing while are not expanded inline" */
+#pragma warn -8004          /* disable Warning W8004 "variable is assigned a value that is never used" */
+#pragma warn -8012          /* disable Warning W8012 "comparing signed and unsigned values" */
 #ifdef WITH_THREADS
 #define __MT__              /* required for _beginthreadex() API in <process.h> */
 #define _MT                 /* required for _errno on BCB6 */
 #endif
-#define HAVE_PROTOTYPE_MKTEMP 1
-#undef HAVE_SYS_UTIME_H
-#define _MSC_VER 1200       /* Treat Borland C++ 5.5 as MSVC6. */
-#endif /* __BORLANDC__ */
+#endif /* HAVE_CLASSIC_BORLAND_COMPILER */
 
-/* Platform specific settings for Visual C++
- * By default, enable ANSI standard C++ includes on Visual C++ 6 and newer
- *   _MSC_VER == 1100 on Microsoft Visual C++ 5.0
- *   _MSC_VER == 1200 on Microsoft Visual C++ 6.0
- *   _MSC_VER == 1300 on Microsoft Visual C++ 7.0
- *   _MSC_VER == 1310 on Microsoft Visual C++ 7.1
- *   _MSC_VER == 1400 on Microsoft Visual C++ 8.0
- */
+/* Platform specific settings for Visual C++ */
 
 #ifdef _MSC_VER
-#if _MSC_VER <= 1200 /* Additional settings for VC6 and older */
-/* disable warning that return type for 'identifier::operator ->' is not a UDT or reference to a UDT */
-    #pragma warning( disable : 4284 )
-#define HAVE_OLD_INTERLOCKEDCOMPAREEXCHANGE 1
-#else
-#define HAVE_VSNPRINTF 1
-#endif /* _MSC_VER <= 1200 */
-
     #pragma warning( disable : 4251 )  /* disable warnings about needed dll-interface */
                                        /* http://www.unknownroad.com/rtfm/VisualStudio/warningC4251.html */
     #pragma warning( disable : 4099 )  /* disable warning about mismatched class and struct keywords */
                                        /* http://alfps.wordpress.com/2010/06/22/cppx-is-c4099-really-a-sillywarning-disabling-msvc-sillywarnings */
     #pragma warning( disable : 4521 )  /* disable warnings about multiple copy constructors and assignment operators,*/
     #pragma warning( disable : 4522 )  /* since these are sometimes necessary for correct overload resolution*/
-
-#if _MSC_VER >= 1400                   /* Additional settings for Visual Studio 2005 and newer */
     #pragma warning( disable : 4996 )  /* disable warnings about "deprecated" C runtime functions */
 #if _MSC_VER < 1900                    /* Warning only available before Visual Studio 2015 */
     #pragma warning( disable : 4351 )  /* disable warnings about "new behavior" when initializing the elements of an array */
 #endif /* _MSC_VER < 1900 */
-#endif /* _MSC_VER >= 1400 */
 #endif /* _MSC_VER */
 
-/* Define if ANSI standard C++ includes use std namespace */
-#define HAVE_STD_NAMESPACE 1
-
-/* Define if the compiler supports std::nothrow */
-#define HAVE_STD__NOTHROW 1
-
-/* Define if the compiler supports operator delete (std::nothrow) */
-#define HAVE_NOTHROW_DELETE 1
-
 /* Define if the compiler supports static_assert */
 #define HAVE_STATIC_ASSERT 1
 
@@ -760,9 +597,6 @@ typedef unsigned long ulong;
 /* Define if the compiler supports __declspec(deprecated("message")) */
 /* #undef HAVE_DECLSPEC_DEPRECATED_MSG */
 
-/* Define if your system has a prototype for std::vfprintf in stdarg.h */
-#define HAVE_PROTOTYPE_STD__VFPRINTF 1
-
 /* Define if your system has off64_t */
 /* #undef HAVE_OFF64_T */
 
@@ -775,39 +609,73 @@ typedef unsigned long ulong;
 /* Define if your system uses _pclose instead of pclose */
 #define HAVE_PCLOSE 1
 
-/* Define if your system provides sigjmp_buf as conditional jmp_buf alternative */
-#define HAVE_SIGJMP_BUF 1
-
 /* Define if we can use C++11 */
 #define HAVE_CXX11 1
 
-#if defined(HAVE_CXX11) && defined(__cplusplus) && __cplusplus < 201103L
+#if defined(HAVE_CXX11)
+# if defined(_MSVC_LANG)
+#  if _MSVC_LANG < 201103L
 #error \
 DCMTK was configured to use C++11 features, but your compiler does not or was not configured to provide them.
+#  endif
+# elif defined(__cplusplus)
+#  if __cplusplus < 201103L
+#error \
+DCMTK was configured to use C++11 features, but your compiler does not or was not configured to provide them.
+#  endif
+# endif
 #endif
 
 /* Define if we can use C++14 */
 /* #undef HAVE_CXX14 */
 
-#if defined(HAVE_CXX14) && defined(__cplusplus) && __cplusplus < 201402L
+#if defined(HAVE_CXX14)
+# if defined(_MSVC_LANG)
+#  if _MSVC_LANG < 201402L
 #error \
 DCMTK was configured to use C++14 features, but your compiler does not or was not configured to provide them.
+#  endif
+# elif defined(__cplusplus)
+#  if __cplusplus < 201402L
+#error \
+DCMTK was configured to use C++14 features, but your compiler does not or was not configured to provide them.
+#  endif
+# endif
 #endif
 
 /* Define if we can use C++17 */
 /* #undef HAVE_CXX17 */
 
-#if defined(HAVE_CXX17) && defined(__cplusplus) && __cplusplus < 201703L
+#if defined(HAVE_CXX17)
+# if defined(_MSVC_LANG)
+#  if _MSVC_LANG < 201703L
 #error \
 DCMTK was configured to use C++17 features, but your compiler does not or was not configured to provide them.
+#  endif
+# elif defined(__cplusplus)
+#  if __cplusplus < 201703L
+#error \
+DCMTK was configured to use C++17 features, but your compiler does not or was not configured to provide them.
+#  endif
+# endif
 #endif
 
+
 /* Define if we can use C++20 */
 /* #undef HAVE_CXX20 */
 
-#if defined(HAVE_CXX20) && defined(__cplusplus) && __cplusplus < 202002L
+#if defined(HAVE_CXX20)
+# if defined(_MSVC_LANG)
+#  if _MSVC_LANG < 202002L
 #error \
 DCMTK was configured to use C++20 features, but your compiler does not or was not configured to provide them.
+#  endif
+# elif defined(__cplusplus)
+#  if __cplusplus < 202002L
+#error \
+DCMTK was configured to use C++20 features, but your compiler does not or was not configured to provide them.
+#  endif
+# endif
 #endif
 
 /* Define if the compiler supports __alignof__ */
@@ -867,9 +735,6 @@ DCMTK was configured to use C++20 features, but your compiler does not or was no
 /* Define if we are supposed to use STL's atomic */
 /* #undef HAVE_STL_ATOMIC */
 
-/* Define if the input iterator category is supported */
-/* #undef HAVE_CONTIGUOUS_ITERATOR_CATEGORY */
-
 /* Feature Tests for the OpenSSL Library */
 
 /* Define if your OpenSSL library provides the RAND_egd function */
@@ -911,13 +776,13 @@ DCMTK was configured to use C++20 features, but your compiler does not or was no
 /* Define if we have the <openssl/provider.h> header file*/
 /* #undef HAVE_OPENSSL_PROVIDER_H */
 
-
 /* Historical C/C++ language features and APIs that are guaranteed by C++98,
- * C89, or POSIX.1-2001 for Posix platforms, and thus not tested anymore.
+ * C99, or POSIX.1-2001 for Posix platforms, or are not used anywhere in DCMTK,
+ * and thus not tested anymore.
  * These macros are deprecated and will be removed from a future version.
  */
-
 #if defined(POISON_DEPRECATED_FEATURE_MACROS) && defined(__GNUC__)
+#pragma GCC poison HAVE_ACCESS
 #pragma GCC poison HAVE_ASSERT_H
 #pragma GCC poison HAVE_BIDIRECTIONAL_ITERATOR_CATEGORY
 #pragma GCC poison HAVE_CLASS_TEMPLATE
@@ -934,12 +799,14 @@ DCMTK was configured to use C++20 features, but your compiler does not or was no
 #pragma GCC poison HAVE_DYNAMIC_CAST
 #pragma GCC poison HAVE_ERRNO_H
 #pragma GCC poison HAVE_EXPLICIT_TEMPLATE_SPECIALIZATION
+#pragma GCC poison HAVE_FCNTL_H
 #pragma GCC poison HAVE_FENV_H
 #pragma GCC poison HAVE_FLOAT_H
 #pragma GCC poison HAVE_FORWARD_ITERATOR_CATEGORY
 #pragma GCC poison HAVE_FSTREAM
 #pragma GCC poison HAVE_FUNCTION_TEMPLATE
 #pragma GCC poison HAVE_GETENV
+#pragma GCC poison HAVE_GETPID
 #pragma GCC poison HAVE_INPUT_ITERATOR_CATEGORY
 #pragma GCC poison HAVE_INTTYPES_H
 #pragma GCC poison HAVE_IOMANIP
@@ -957,40 +824,59 @@ DCMTK was configured to use C++20 features, but your compiler does not or was no
 #pragma GCC poison HAVE_MEMCPY
 #pragma GCC poison HAVE_MEMMOVE
 #pragma GCC poison HAVE_MEMSET
+#pragma GCC poison HAVE_MKTEMP
+#pragma GCC poison HAVE_NOTHROW_DELETE
 #pragma GCC poison HAVE_OUTPUT_ITERATOR_CATEGORY
 #pragma GCC poison HAVE_PROTOTYPE_ISINF
 #pragma GCC poison HAVE_PROTOTYPE_ISNAN
+#pragma GCC poison HAVE_PROTOTYPE_MKTEMP
+#pragma GCC poison HAVE_PROTOTYPE_STD__ISINF
+#pragma GCC poison HAVE_PROTOTYPE_STD__ISNAN
+#pragma GCC poison HAVE_PROTOTYPE_STD__VFPRINTF
+#pragma GCC poison HAVE_PROTOTYPE_VSNPRINTF
 #pragma GCC poison HAVE_RANDOM_ACCESS_ITERATOR_CATEGORY
 #pragma GCC poison HAVE_REINTERPRET_CAST
 #pragma GCC poison HAVE_SETJMP_H
 #pragma GCC poison HAVE_SIGNAL_H
 #pragma GCC poison HAVE_SSTREAM
+#pragma GCC poison HAVE_STAT
 #pragma GCC poison HAVE_STATIC_CAST
 #pragma GCC poison HAVE_STATIC_TEMPLATE_METHOD
 #pragma GCC poison HAVE_STDARG_H
 #pragma GCC poison HAVE_STDBOOL_H
 #pragma GCC poison HAVE_STDDEF_H
+#pragma GCC poison HAVE_STDINT_H
 #pragma GCC poison HAVE_STDIO_H
 #pragma GCC poison HAVE_STDLIB_H
+#pragma GCC poison HAVE_STD_NAMESPACE
+#pragma GCC poison HAVE_STD__NOTHROW
 #pragma GCC poison HAVE_STRCHR
+#pragma GCC poison HAVE_STRDUP
 #pragma GCC poison HAVE_STRERROR
 #pragma GCC poison HAVE_STRING_H
 #pragma GCC poison HAVE_STRSTR
 #pragma GCC poison HAVE_STRSTREAM
 #pragma GCC poison HAVE_STRTOUL
+#pragma GCC poison HAVE_SYS_STAT_H
+/* #pragma GCC poison HAVE_SYS_TYPES_H */  /* this macro is used in some Linux system header files. */
 #pragma GCC poison HAVE_TEMPNAM
 #pragma GCC poison HAVE_TIME_H
 #pragma GCC poison HAVE_TMPNAM
 #pragma GCC poison HAVE_TYPENAME
 #pragma GCC poison HAVE_VPRINTF
+#pragma GCC poison HAVE_VSNPRINTF
 #pragma GCC poison HAVE_WCHAR_H
 #pragma GCC poison HAVE_WCSTOMBS
 #pragma GCC poison HAVE_WCTYPE_H
 #pragma GCC poison SIZEOF_CHAR
+#pragma GCC poison SIZEOF_DOUBLE
+#pragma GCC poison SIZEOF_FLOAT
+#pragma GCC poison SIZEOF_SHORT
 #pragma GCC poison STDC_HEADERS
 #endif
 
 #if !defined(POISON_DEPRECATED_FEATURE_MACROS) || !defined(__GNUC__)
+#define HAVE_ACCESS 1
 #define HAVE_ASSERT_H 1
 #define HAVE_BIDIRECTIONAL_ITERATOR_CATEGORY 1
 #define HAVE_CLASS_TEMPLATE 1
@@ -1007,12 +893,14 @@ DCMTK was configured to use C++20 features, but your compiler does not or was no
 #define HAVE_DYNAMIC_CAST 1
 #define HAVE_ERRNO_H 1
 #define HAVE_EXPLICIT_TEMPLATE_SPECIALIZATION 1
+#define HAVE_FCNTL_H 1
 #define HAVE_FENV_H 1
 #define HAVE_FLOAT_H 1
 #define HAVE_FORWARD_ITERATOR_CATEGORY 1
 #define HAVE_FSTREAM 1
 #define HAVE_FUNCTION_TEMPLATE 1
 #define HAVE_GETENV 1
+#define HAVE_GETPID 1
 #define HAVE_INPUT_ITERATOR_CATEGORY 1
 #define HAVE_INTTYPES_H 1
 #define HAVE_IOMANIP 1
@@ -1030,32 +918,47 @@ DCMTK was configured to use C++20 features, but your compiler does not or was no
 #define HAVE_MEMCPY 1
 #define HAVE_MEMMOVE 1
 #define HAVE_MEMSET 1
+#define HAVE_MKTEMP 1
+#define HAVE_NOTHROW_DELETE 1
 #define HAVE_OUTPUT_ITERATOR_CATEGORY 1
 #define HAVE_PROTOTYPE_ISINF 1
 #define HAVE_PROTOTYPE_ISNAN 1
+#define HAVE_PROTOTYPE_MKTEMP 1
+#define HAVE_PROTOTYPE_STD__ISINF 1
+#define HAVE_PROTOTYPE_STD__ISNAN 1
+#define HAVE_PROTOTYPE_STD__VFPRINTF 1
+#define HAVE_PROTOTYPE_VSNPRINTF 1
 #define HAVE_RANDOM_ACCESS_ITERATOR_CATEGORY 1
 #define HAVE_REINTERPRET_CAST 1
 #define HAVE_SETJMP_H 1
 #define HAVE_SIGNAL_H 1
 #define HAVE_SSTREAM 1
+#define HAVE_STAT 1
 #define HAVE_STATIC_CAST 1
 #define HAVE_STATIC_TEMPLATE_METHOD 1
 #define HAVE_STDARG_H 1
 #define HAVE_STDBOOL_H 1
 #define HAVE_STDDEF_H 1
+#define HAVE_STDINT_H 1
 #define HAVE_STDIO_H 1
 #define HAVE_STDLIB_H 1
+#define HAVE_STD_NAMESPACE 1
+#define HAVE_STD__NOTHROW 1
 #define HAVE_STRCHR 1
+#define HAVE_STRDUP 1
 #define HAVE_STRERROR 1
 #define HAVE_STRING_H 1
 #define HAVE_STRSTR 1
 #define HAVE_STRSTREAM 1
 #define HAVE_STRTOUL 1
+#define HAVE_SYS_STAT_H 1
+#define HAVE_SYS_TYPES_H 1
 #define HAVE_TEMPNAM 1
 #define HAVE_TIME_H 1
 #define HAVE_TMPNAM 1
 #define HAVE_TYPENAME 1
 #define HAVE_VPRINTF 1
+#define HAVE_VSNPRINTF 1
 #define HAVE_WCHAR_H 1
 #define HAVE_WCSTOMBS 1
 #define HAVE_WCTYPE_H 1
@@ -1069,29 +972,56 @@ DCMTK was configured to use C++20 features, but your compiler does not or was no
 
 #if defined(POISON_DEPRECATED_FEATURE_MACROS) && defined(__GNUC__)
 #pragma GCC poison C_INLINE
+#pragma GCC poison HAVE_BCMP
 #pragma GCC poison HAVE_BCOPY
+#pragma GCC poison HAVE_CONTIGUOUS_ITERATOR_CATEGORY
+#pragma GCC poison HAVE_DECLARATION_FP_EXCEPT_T
 #pragma GCC poison HAVE_DECLARATION_STD__IOS_BASE__OPENMODE
 #pragma GCC poison HAVE_DOPRNT
 #pragma GCC poison HAVE_EMPTY_ARGC_ARGV
+#pragma GCC poison HAVE_FINITE
 #pragma GCC poison HAVE_FSTREAM_H
+#pragma GCC poison HAVE_GETRUSAGE
+#pragma GCC poison HAVE_INDEX
+#pragma GCC poison HAVE_INTP_ACCEPT
+#pragma GCC poison HAVE_INTP_GETSOCKOPT
 #pragma GCC poison HAVE_IOMANIP_H
 #pragma GCC poison HAVE_IOSTREAM_H
 #pragma GCC poison HAVE_IOS_NOCREATE
+#pragma GCC poison HAVE_ITOA
 #pragma GCC poison HAVE_LIBIOSTREAM
+#pragma GCC poison HAVE_LIBNSL
+#pragma GCC poison HAVE_LIBSOCKET
+#pragma GCC poison HAVE_LISTEN
 #pragma GCC poison HAVE_LONGLONG
+#pragma GCC poison HAVE_MALLOC_H
 #pragma GCC poison HAVE_MEMORY_H
 #pragma GCC poison HAVE_NDIR_H
 #pragma GCC poison HAVE_NEW_H
 #pragma GCC poison HAVE_OLD_READDIR_R
+#pragma GCC poison HAVE_PROTOTYPE_FINITE
+#pragma GCC poison HAVE_PROTOTYPE_MKSTEMP
+#pragma GCC poison HAVE_PROTOTYPE_NANOSLEEP
 #pragma GCC poison HAVE_PROTOTYPE_STD__FINITE
 #pragma GCC poison HAVE_PROTOTYPE_WAIT3
+#pragma GCC poison HAVE_PROTOTYPE_FEENABLEEXCEPT
+#pragma GCC poison HAVE_PROTOTYPE__FPCLASSF
+#pragma GCC poison HAVE_RINDEX
+#pragma GCC poison HAVE_SIGJMP_BUF
 #pragma GCC poison HAVE_SSTREAM_H
 #pragma GCC poison HAVE_STAT_H
 #pragma GCC poison HAVE_STREAMBUF_H
 #pragma GCC poison HAVE_STRSTREAM_H
 #pragma GCC poison HAVE_STRSTREA_H
+#pragma GCC poison HAVE_SYSTEM_ERROR
+#pragma GCC poison HAVE_SYS_ERRNO_H
 #pragma GCC poison HAVE_SYS_NDIR_H
+#pragma GCC poison HAVE_TUPLE
+#pragma GCC poison HAVE_UCHAR_TYPEDEF
+#pragma GCC poison HAVE_UINT_TYPEDEF
 #pragma GCC poison HAVE_ULONGLONG
+#pragma GCC poison HAVE_ULONG_TYPEDEF
+#pragma GCC poison HAVE_USHORT_TYPEDEF
 #pragma GCC poison HAVE_WAIT3
 #pragma GCC poison INCLUDE_LIBC_H_AS_CXX
 #pragma GCC poison INCLUDE_MATH_H_AS_CXX
@@ -1099,37 +1029,68 @@ DCMTK was configured to use C++20 features, but your compiler does not or was no
 #pragma GCC poison TM_IN_SYS_TIME
 #endif
 
+#if !defined(POISON_DEPRECATED_FEATURE_MACROS) || !defined(__GNUC__)
 /* #undef C_INLINE */
+/* #undef HAVE_BCMP */
 /* #undef HAVE_BCOPY */
+/* #undef HAVE_CONTIGUOUS_ITERATOR_CATEGORY */
+/* #undef HAVE_DECLARATION_FP_EXCEPT_T */
 /* #undef HAVE_DECLARATION_STD__IOS_BASE__OPENMODE */
 /* #undef HAVE_DOPRNT */
 /* #undef HAVE_EMPTY_ARGC_ARGV */
+/* #undef HAVE_FINITE */
 /* #undef HAVE_FSTREAM_H */
+/* #undef HAVE_GETRUSAGE */
+/* #undef HAVE_INDEX */
+/* #undef HAVE_INTP_ACCEPT */
+/* #undef HAVE_INTP_GETSOCKOPT */
 /* #undef HAVE_IOMANIP_H */
 /* #undef HAVE_IOSTREAM_H */
 /* #undef HAVE_IOS_NOCREATE */
+/* #undef HAVE_ITOA */
 /* #undef HAVE_LIBIOSTREAM */
+/* #undef HAVE_LIBNSL */
+/* #undef HAVE_LIBSOCKET */
+/* #undef HAVE_LISTEN */
 /* #undef HAVE_LONGLONG */
+/* #undef HAVE_MALLOC_H */
 /* #undef HAVE_MEMORY_H */
 /* #undef HAVE_NDIR_H */
 /* #undef HAVE_NEW_H */
 /* #undef HAVE_OLD_READDIR_R */
+/* #undef HAVE_PROTOTYPE_FINITE */
+/* #undef HAVE_PROTOTYPE_MKSTEMP */
+/* #undef HAVE_PROTOTYPE_NANOSLEEP */
 /* #undef HAVE_PROTOTYPE_STD__FINITE */
 /* #undef HAVE_PROTOTYPE_WAIT3 */
+/* #undef HAVE_PROTOTYPE_FEENABLEEXCEPT */
+/* #undef HAVE_PROTOTYPE__FPCLASSF */
+/* #undef HAVE_RINDEX */
+/* #undef HAVE_SIGJMP_BUF */
 /* #undef HAVE_SSTREAM_H */
 /* #undef HAVE_STAT_H */
 /* #undef HAVE_STREAMBUF_H */
 /* #undef HAVE_STRSTREAM_H */
 /* #undef HAVE_STRSTREA_H */
+/* #undef HAVE_SYSTEM_ERROR */
+/* #undef HAVE_SYS_ERRNO_H */
 /* #undef HAVE_SYS_NDIR_H */
+/* #undef HAVE_TUPLE */
+/* #undef HAVE_UCHAR_TYPEDEF */
+/* #undef HAVE_UINT_TYPEDEF */
 /* #undef HAVE_ULONGLONG */
+/* #undef HAVE_ULONG_TYPEDEF */
+/* #undef HAVE_USHORT_TYPEDEF */
 /* #undef HAVE_WAIT3 */
 /* #undef INCLUDE_LIBC_H_AS_CXX */
 /* #undef INCLUDE_MATH_H_AS_CXX */
 /* #undef RETSIGTYPE */
 /* #undef TM_IN_SYS_TIME */
 /* #undef __CHAR_UNSIGNED__ */
-
+#define SIZEOF_DOUBLE 8
+#define SIZEOF_FLOAT 4
+#define SIZEOF_SHORT 2
+#endif
 
 /* Historical feature tests for BSD socket functions, which exist on POSIX
  * systems and on Windows. These are not tested anymore.
