@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2022, OFFIS e.V.
+ *  Copyright (C) 1994-2025, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -80,7 +80,8 @@ const unsigned short OFM_dcmect   = 35;
  *  These constants can be used in addition to the general purpose ones
  *  defined in module ofstd.
  */
-//@{
+///@{
+
 /// Invalid tag
 extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_InvalidTag;
 /// Tag not found
@@ -179,16 +180,32 @@ extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_CannotWriteJsonInlineBinar
 extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_XMLParseError;
 /// XML validation failure
 extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_XMLValidationFailure;
-/// SOP class mismatch
+/// SOP Class mismatch
 extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_SOPClassMismatch;
 /// Unknown UID name: No mapping to UID value defined
 extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_UnknownUIDName;
 /// Cannot write IS/DS string as JSON number
-extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_CannotWriteStringAsJsonNumber;
+extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_CannotWriteStringAsJSONNumber;
+/// Cannot write bulk data file
+extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_CannotWriteBulkDataFile;
+/// JSON encoding not supported for encapsulated multi-frame pixel data
+extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_CannotWriteJSONMultiframe;
+/// Not the expected Type while parsing the JSON file
+extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_InvalidJSONType;
+/// Invalid JSON content
+extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_InvalidJSONContent;
+/// BulkDataURI not yet supported
+extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_BulkDataURINotSupported;
+/// Unsupported URI type
+extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_UnsupportedURIType;
+/// Execution of command line failed
+extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_CommandLineFailed;
 
-//@}
+///@}
 
-// status code constants
+/** @name status code constants for module dcmdata.
+ */
+///@{
 
 /// error, cannot select specific character set
 extern DCMTK_DCMDATA_EXPORT const unsigned short EC_CODE_CannotSelectCharacterSet;
@@ -199,4 +216,6 @@ extern DCMTK_DCMDATA_EXPORT const unsigned short EC_CODE_CannotConvertToXML;
 /// error, cannot determine start fragment (of compressed pixel data)
 extern DCMTK_DCMDATA_EXPORT const unsigned short EC_CODE_CannotDetermineStartFragment;
 
+///@}
+
 #endif /* !DCERROR_H */
