@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2021, OFFIS e.V.
+ *  Copyright (C) 1994-2025, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were partly developed by
@@ -94,6 +94,7 @@
 /*
 ** Required Include Files
 */
+#include "dcmtk/ofstd/ofdeprec.h"
 #include "dcmtk/dcmnet/dicom.h"
 #include "dcmtk/dcmnet/lst.h"
 #include "dcmtk/dcmnet/dul.h"
@@ -129,9 +130,9 @@ enum T_ASC_NetworkRole
 
 struct DCMTK_DCMNET_EXPORT T_ASC_Network
 {
-    T_ASC_NetworkRole   role;
+    T_ASC_NetworkRole role;
     int               acceptorPort;
-    DUL_NETWORKKEY      *network;
+    DUL_NETWORKKEY   *network;
 };
 
 
@@ -142,22 +143,23 @@ struct DCMTK_DCMNET_EXPORT T_ASC_Network
 
 
 /* not defined anywhere (I think) but a hard limitation for now.
- * DICOM (1998) defines 22 transfer syntaxes, this upper limit
- * should allow for sufficiently many private transfer syntaxes.
+ * DICOM (2024) defines more than 50 transfer syntaxes for network
+ * communication, so this upper limit should allow for sufficiently
+ * many private transfer syntaxes.
  */
-#define DICOM_MAXTRANSFERSYNTAXES 50
+#define DICOM_MAXTRANSFERSYNTAXES 128
 
 
 typedef DUL_PRESENTATIONCONTEXTID T_ASC_PresentationContextID;
 
 enum T_ASC_P_ResultReason
 { /* Part 8, pp 45. */
-    ASC_P_ACCEPTANCE              = 0,
-    ASC_P_USERREJECTION               = 1,
-    ASC_P_NOREASON                  = 2,
-    ASC_P_ABSTRACTSYNTAXNOTSUPPORTED    = 3,
-    ASC_P_TRANSFERSYNTAXESNOTSUPPORTED  = 4,
-    ASC_P_NOTYETNEGOTIATED              = 255
+    ASC_P_ACCEPTANCE                   = 0,
+    ASC_P_USERREJECTION                = 1,
+    ASC_P_NOREASON                     = 2,
+    ASC_P_ABSTRACTSYNTAXNOTSUPPORTED   = 3,
+    ASC_P_TRANSFERSYNTAXESNOTSUPPORTED = 4,
+    ASC_P_NOTYETNEGOTIATED             = 255
 };
 
 enum T_ASC_SC_ROLE
@@ -172,19 +174,19 @@ enum T_ASC_SC_ROLE
 struct DCMTK_DCMNET_EXPORT T_ASC_PresentationContext
 {
     T_ASC_PresentationContextID presentationContextID;
-    DIC_UI      abstractSyntax;
-    unsigned char     transferSyntaxCount;
-    DIC_UI    proposedTransferSyntaxes[DICOM_MAXTRANSFERSYNTAXES];
-    DIC_UI      acceptedTransferSyntax;
-    T_ASC_P_ResultReason  resultReason;
-    T_ASC_SC_ROLE     proposedRole;
-    T_ASC_SC_ROLE   acceptedRole;
+    DIC_UI abstractSyntax;
+    unsigned char transferSyntaxCount;
+    DIC_UI proposedTransferSyntaxes[DICOM_MAXTRANSFERSYNTAXES];
+    DIC_UI acceptedTransferSyntax;
+    T_ASC_P_ResultReason resultReason;
+    T_ASC_SC_ROLE proposedRole;
+    T_ASC_SC_ROLE acceptedRole;
 };
 
 enum T_ASC_RejectParametersResult
 {
-    ASC_RESULT_REJECTEDPERMANENT      = 1,
-    ASC_RESULT_REJECTEDTRANSIENT      = 2
+    ASC_RESULT_REJECTEDPERMANENT = 1,
+    ASC_RESULT_REJECTEDTRANSIENT = 2
 };
 
 enum T_ASC_RejectParametersSource
@@ -216,6 +218,13 @@ struct DCMTK_DCMNET_EXPORT T_ASC_RejectParameters
     T_ASC_RejectParametersReason reason;
 };
 
+struct DCMTK_DCMNET_EXPORT T_ASC_ImplementationIdentification
+{
+    T_ASC_ImplementationIdentification();
+
+    DIC_UI ourImplementationClassUID;
+    DIC_SH ourImplementationVersionName;
+};
 
 struct DCMTK_DCMNET_EXPORT T_ASC_Parameters
 {
@@ -233,7 +242,6 @@ struct DCMTK_DCMNET_EXPORT T_ASC_Parameters
 
     long ourMaxPDUReceiveSize;    /* we say what we can receive */
     long theirMaxPDUReceiveSize;  /* they say what we can send */
-
 };
 
 /*
@@ -263,6 +271,8 @@ struct DCMTK_DCMNET_EXPORT T_ASC_Association
 /** network instance creation function (constructor)
  *  @param role association acceptor, requestor or both
  *  @param acceptorPort acceptor port for incoming connections.
+ *    If for an acceptor 0 is provided, the OS will assign
+ *    an unused ports on its own.
  *    For association requestors, zero should be passed here.
  *  @param timeout timeout for network operations, in seconds
  *  @param network T_ASC_Network will be allocated and returned in this parameter
@@ -289,11 +299,23 @@ DCMTK_DCMNET_EXPORT OFCondition ASC_dropNetwork(T_ASC_Network ** network);
 
 /* create association parameters and initialize with default values */
 DCMTK_DCMNET_EXPORT OFCondition
+ASC_createAssociationParameters(
+    T_ASC_Parameters ** params,
+    long maxReceivePDUSize,
+    Sint32 tcpConnectTimeout,
+    const T_ASC_ImplementationIdentification& implIdentification = T_ASC_ImplementationIdentification());
+
+/*
+ * same as before, but uses value of the global dcmConnectionTimeout variable.
+ * Please note that this function is deprecated and will be removed in a future
+ * release.  Use the previous function with the timeout parameter instead.
+ */
+OFdeprecated DCMTK_DCMNET_EXPORT OFCondition
 ASC_createAssociationParameters(
     T_ASC_Parameters ** params,
     long maxReceivePDUSize);
 
- /*
+/*
   * Free an association parameters structure and embedded information.
   * You do not usually need to do this since the parameters structure will
   * be noted in the association structure and automatically freed when an
@@ -309,6 +331,12 @@ ASC_setTransportLayerType(
     T_ASC_Parameters * params,
     OFBool useSecureLayer);
 
+/* set IP protocol family */
+DCMTK_DCMNET_EXPORT OFCondition
+ASC_setProtocolFamily(
+    T_ASC_Parameters * params,
+    T_ASC_ProtocolFamily protocolFamily);
+
  /*
   * Copies the provided Application Titles in the association parameters.
   */
@@ -677,7 +705,8 @@ ASC_receiveAssociation(
     unsigned long *associatePDUlength=NULL,
     OFBool useSecureLayer=OFFalse,
     DUL_BLOCKOPTIONS block=DUL_BLOCK,
-    int timeout=0);
+    int timeout=0,
+    const T_ASC_ImplementationIdentification& implIdentification = T_ASC_ImplementationIdentification());
 
 DCMTK_DCMNET_EXPORT OFCondition
 ASC_acknowledgeAssociation(
@@ -713,14 +742,21 @@ ASC_closeTransportConnection(T_ASC_Association * association);
 DCMTK_DCMNET_EXPORT OFCondition
 ASC_destroyAssociation(T_ASC_Association ** association);
 
+/** this function sets a flag in the association that the current process
+ *  is the parent process after a fork() operation and that the association
+ *  will be handled by the child process. In the case of TLS connections,
+ *  this prevents the destructor from calling SSL_shutdown().
+ */
+DCMTK_DCMNET_EXPORT void ASC_setParentProcessMode(T_ASC_Association *association);
+
 /// @deprecated Please use OFString& ASC_printRejectParameters(OFString&, T_ASC_RejectParameters*) instead.
-DCMTK_DCMNET_EXPORT void
+OFdeprecated DCMTK_DCMNET_EXPORT void
 ASC_printRejectParameters(
     FILE *f,
     const T_ASC_RejectParameters *rej);
 
 /// @deprecated Please use OFString& ASC_printRejectParameters(OFString&, T_ASC_RejectParameters*) instead.
-DCMTK_DCMNET_EXPORT void
+OFdeprecated DCMTK_DCMNET_EXPORT void
 ASC_printRejectParameters(
     STD_NAMESPACE ostream& out,
     const T_ASC_RejectParameters *rej);
@@ -732,7 +768,7 @@ ASC_printRejectParameters(
  * @deprecated Please use OFString& ASC_dumpParameters(OFString&, T_ASC_Parameters *,
  *             ASC_associateType) instead.
  */
-DCMTK_DCMNET_EXPORT void
+OFdeprecated DCMTK_DCMNET_EXPORT void
 ASC_dumpParameters(T_ASC_Parameters * params, STD_NAMESPACE ostream& outstream);
 
  /*
@@ -740,14 +776,14 @@ ASC_dumpParameters(T_ASC_Parameters * params, STD_NAMESPACE ostream& outstream);
   * (debugging aid)
   */
 /// @deprecated You should dump the complete T_ASC_Parameters with ASC_dumpParameters() instead.
-DCMTK_DCMNET_EXPORT void
+OFdeprecated DCMTK_DCMNET_EXPORT void
 ASC_dumpPresentationContext(T_ASC_PresentationContext * presentationContext, STD_NAMESPACE ostream& outstream);
 
 /**
  * @deprecated Please use OFString& ASC_dumpParameters(OFString&, T_ASC_Parameters*,
  *             ASC_associateType) instead.
  */
-DCMTK_DCMNET_EXPORT void
+OFdeprecated DCMTK_DCMNET_EXPORT void
 ASC_dumpConnectionParameters(T_ASC_Association *association, STD_NAMESPACE ostream& outstream);
 
 /** Converts given ASC role to string (e.g. for printing)
