@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2021, OFFIS e.V.
+ *  Copyright (C) 2000-2025, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -29,6 +29,13 @@
 #include "dcmtk/dcmsr/dsrtypes.h"
 
 
+// include this file in doxygen documentation
+
+/** @file dsrcomvl.h
+ *  @brief definitions for class DSRCompositeReferenceValue
+ */
+
+
 /*---------------------*
  *  class declaration  *
  *---------------------*/
@@ -74,23 +81,23 @@ class DCMTK_DCMSR_EXPORT DSRCompositeReferenceValue
      */
     DSRCompositeReferenceValue &operator=(const DSRCompositeReferenceValue &referenceValue);
 
-    /** comparison operator "equal"
-     ** @param  referenceValue  reference value that should be compared to the current one
-     ** @return OFTrue if both composite reference values are equal, OFFalse otherwise
-     */
-    OFBool operator==(const DSRCompositeReferenceValue &referenceValue) const;
-
-    /** comparison operator "not equal"
-     ** @param  referenceValue  reference value that should be compared to the current one
-     ** @return OFTrue if both composite reference values are not equal, OFFalse otherwise
-     */
-    OFBool operator!=(const DSRCompositeReferenceValue &referenceValue) const;
-
     /** clear all internal variables.
      *  Since an empty reference value is invalid the reference becomes invalid afterwards.
      */
     virtual void clear();
 
+    /** check whether values are "equal"
+     ** @param  referenceValue  reference value that should be compared to the current one
+     ** @return OFTrue if both composite reference values are equal, OFFalse otherwise
+     */
+    OFBool isEqual(const DSRCompositeReferenceValue &referenceValue) const;
+
+    /** check whether values are "not equal"
+     ** @param  referenceValue  reference value that should be compared to the current one
+     ** @return OFTrue if both composite reference values are not equal, OFFalse otherwise
+     */
+    OFBool isNotEqual(const DSRCompositeReferenceValue &referenceValue) const;
+
     /** check whether the current reference value is valid.
      *  The reference value is valid if SOP class UID and SOP instance UID are valid.  See
      *  checkSOPClassUID() and checkSOPInstanceUID() methods for details.
@@ -171,12 +178,18 @@ class DCMTK_DCMSR_EXPORT DSRCompositeReferenceValue
      *  @param  annexNumber  reference to the variable where the current annex number is stored.
      *                       Value is increased automatically by 1 after a new entry has been added.
      *  @param  flags        flag used to customize the output (see DSRTypes::HF_xxx)
+     *  @param  urlPrefix    optional URL prefix used for hyperlink to referenced composite object
+     ** @note Please note that using parameter 'urlPrefix' can lead to security issues, as an
+     *        attacker could misuse it to potentially inject dangerous content into the HTML/XHTML
+     *        output.  The value of this parameter is not checked.  This is also true for derived
+     *        classes.
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition renderHTML(STD_NAMESPACE ostream &docStream,
                                    STD_NAMESPACE ostream &annexStream,
                                    size_t &annexNumber,
-                                   const size_t flags) const;
+                                   const size_t flags,
+                                   const char *urlPrefix = NULL) const;
 
     /** get SOP class UID
      ** @return current SOP class UID (might be invalid or an empty string)
@@ -396,4 +409,27 @@ class DCMTK_DCMSR_EXPORT DSRCompositeReferenceValue
 };
 
 
+/*------------------------*
+ *  comparison operators  *
+ *------------------------*/
+
+/** equality operator.
+ *  Internally, the DSRCompositeReferenceValue::isEqual() method is used.
+ *  @param  lhs  left-hand side
+ *  @param  rhs  right-hand side
+ *  @return OFTrue if 'lhs' and 'rhs' are equal, OFFalse otherwise
+ */
+DCMTK_DCMSR_EXPORT OFBool operator==(const DSRCompositeReferenceValue &lhs,
+                                     const DSRCompositeReferenceValue &rhs);
+
+/** inequality operator.
+ *  Internally, the DSRCompositeReferenceValue::isNotEqual() method is used.
+ *  @param  lhs  left-hand side
+ *  @param  rhs  right-hand side
+ *  @return OFTrue if 'lhs' and 'rhs' are not equal, OFFalse otherwise
+ */
+DCMTK_DCMSR_EXPORT OFBool operator!=(const DSRCompositeReferenceValue &lhs,
+                                     const DSRCompositeReferenceValue &rhs);
+
+
 #endif
