@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2021, OFFIS e.V.
+ *  Copyright (C) 2000-2025, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -32,6 +32,7 @@
 #include "dcmtk/dcmsr/dsrrefin.h"
 #include "dcmtk/dcmsr/dsrcsidl.h"
 
+#include "dcmtk/dcmdata/dcvras.h"
 #include "dcmtk/dcmdata/dcvrcs.h"
 #include "dcmtk/dcmdata/dcvrda.h"
 #include "dcmtk/dcmdata/dcvrds.h"
@@ -196,11 +197,20 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      ** @param  stream      output stream to which the HTML/XHTML document is written
      *  @param  flags       optional flag used to customize the output (see DSRTypes::HF_xxx)
      *  @param  styleSheet  optional filename/URL of a Cascading Style Sheet (CSS)
+     *  @param  urlPrefix   optional URL prefix used for hyperlinks to referenced composite
+     *                      objects.  If NULL, the default URL prefix is used, which is
+     *                      defined by DEFAULT_HTML_HYPERLINK_PREFIX_FOR_COMPOSITE_OBJECTS
+     *                      (http://localhost/dicom.cgi).
+     ** @note Please note that using the parameter 'styleSheet' or 'urlPrefix' can lead to
+     *        security issues, as an attacker could misuse them to potentially inject dangerous
+     *        content into the HTML/XHTML output.  The values passed to these parameters are not
+     *        checked, neither the URL and prefix nor the content of the specified CSS file.
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition renderHTML(STD_NAMESPACE ostream &stream,
                                    const size_t flags = 0,
-                                   const char *styleSheet = NULL);
+                                   const char *styleSheet = NULL,
+                                   const char *urlPrefix = NULL);
 
 
   // --- get/set misc attributes ---
@@ -405,6 +415,9 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     virtual DSRSOPInstanceReferenceList &getPertinentOtherEvidence();
 
     /** get list of referenced SOP instances significantly related to the current SOP instance.
+     *  However, the same instances shall not be referenced in the Current Requested Procedure
+     *  Evidence Sequence, Pertinent Other Evidence Sequence, Predecessor Documents Sequence or
+     *  Identical Documents Sequence.
      *  The DICOM standard states: "Such referenced Instances may include equivalent documents or
      *  renderings of this document. [...] Required if the identity of a CDA Document equivalent
      *  to the current SOP Instance is known at the time of creation of this SOP instance. May be
@@ -524,6 +537,14 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     virtual OFCondition getPatientSex(OFString &value,
                                       const signed long pos = 0) const;
 
+    /** get patient's age
+     ** @param  value  reference to variable in which the value should be stored
+     *  @param  pos    index of the value to get (0..vm-1), -1 for all components
+     ** @return status, EC_Normal if successful, an error code otherwise
+     */
+    virtual OFCondition getPatientAge(OFString &value,
+                                      const signed long pos = 0) const;
+
     /** get patient's size
      ** @param  value  reference to variable in which the value should be stored
      *  @param  pos    index of the value to get (0..vm-1), -1 for all components
@@ -800,6 +821,14 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     virtual OFCondition setPatientSex(const OFString &value,
                                       const OFBool check = OFTrue);
 
+    /** set patient's age
+     ** @param  value  value to be set (single value only) or "" for no value
+     *  @param  check  check 'value' for conformance with VR (AS) and VM (1) if enabled
+     ** @return status, EC_Normal if successful, an error code otherwise
+     */
+    virtual OFCondition setPatientAge(const OFString &value,
+                                      const OFBool check = OFTrue);
+
     /** set patient's size
      ** @param  value  value to be set (single value only) or "" for no value
      *  @param  check  check 'value' for conformance with VR (DS) and VM (1) if enabled
@@ -1056,14 +1085,14 @@ class DCMTK_DCMSR_EXPORT DSRDocument
 
     /** create a new document.
      *  A new SOP instance is only created if the current document type was valid/supported.
-     *  Please note that the current document is deleted (cleared).
+     *  Please note that the current document is deleted (cleared) by this method.
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition createNewDocument();
 
     /** create a new document of the specified type.
      *  A new SOP instance is only created if the current document type was valid/supported.
-     *  Please note that the current document is deleted by this method.
+     *  Please note that the current document is deleted (cleared) by this method.
      ** @param  documentType  type of the new SR document (see DSRTypes::E_DocumentType)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
@@ -1275,22 +1304,26 @@ class DCMTK_DCMSR_EXPORT DSRDocument
                                const size_t flags);
 
     /** render list of referenced SOP instances in HTML/XHTML format
-     ** @param  stream   output stream to which the HTML/XHTML document is written
-     *  @param  refList  list of referenced SOP instances to be rendered
-     *  @param  flags    flag used to customize the output (see DSRTypes::HF_xxx)
+     ** @param  stream     output stream to which the HTML/XHTML document is written
+     *  @param  refList    list of referenced SOP instances to be rendered
+     *  @param  flags      flag used to customize the output (see DSRTypes::HF_xxx)
+     *  @param  urlPrefix  optional URL prefix used for hyperlinks to referenced composite objects
      */
     void renderHTMLReferenceList(STD_NAMESPACE ostream &stream,
                                  DSRSOPInstanceReferenceList &refList,
-                                 const size_t flags);
+                                 const size_t flags,
+                                 const char *urlPrefix = NULL);
 
     /** render list of referenced SOP instances in HTML/XHTML format
-     ** @param  stream   output stream to which the HTML/XHTML document is written
-     *  @param  refList  list of referenced SOP instances to be rendered
-     *  @param  flags    flag used to customize the output (see DSRTypes::HF_xxx)
+     ** @param  stream     output stream to which the HTML/XHTML document is written
+     *  @param  refList    list of referenced SOP instances to be rendered
+     *  @param  flags      flag used to customize the output (see DSRTypes::HF_xxx)
+     *  @param  urlPrefix  optional URL prefix used for hyperlinks to referenced composite objects
      */
     void renderHTMLReferenceList(STD_NAMESPACE ostream &stream,
                                  DSRReferencedInstanceList &refList,
-                                 const size_t flags);
+                                 const size_t flags,
+                                 const char *urlPrefix = NULL);
 
     /** check the given dataset before reading.
      *  This methods checks whether the dataset contains at least the DICOM attributes SOP class UID
@@ -1396,6 +1429,8 @@ class DCMTK_DCMSR_EXPORT DSRDocument
 
     // --- Patient Study Module (U) ---
 
+    /// Patient's Age: (AS, 1, 3)
+    DcmAgeString        PatientAge;
     /// Patient's Size: (DS, 1, 3)
     DcmDecimalString    PatientSize;
     /// Patient's Weight: (DS, 1, 3)
