@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2014-2017, OFFIS e.V.
+ *  Copyright (C) 2014-2022, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -33,7 +33,7 @@
 
 // include <type_traits> for "std::is_default_constructible"
 // to recover from compiler insanity (Visual Studio 12+).
-#if defined(_MSC_VER) && _MSC_VER >= 1700
+#if defined(_MSC_VER)
 #include <type_traits>
 #endif
 
@@ -136,25 +136,10 @@ class OFdefault_optional_traits
     template<typename X>
     static yes_type sfinae(consume<sizeof *new X>*);
 #elif defined(_MSC_VER)
-#if _MSC_VER < 1700
-    // Workaround bug in Visual Studio.
-    // On these broken compilers, the argument is not evaluated
-    // unless we require them to evaluate it for choosing which
-    // specialization should be instantiated.
-    template<size_t,size_t>
-    struct consume{};
-    template<size_t X>
-    struct consume<X,X> { typedef void type; };
-    // sfinae overload working for value-initializable Xs, that's as
-    // close as we get on these broken compilers
-    template<typename X>
-    static yes_type sfinae(typename consume<sizeof X(),sizeof X()>::type*);
-#else
     // Visual Studio 2012 is completely broken, but it has std::is_default_constructible
     // Note: this tests constructibility, but not if WE can construct this.
     template<typename X>
     static yes_type sfinae(typename OFenable_if<std::is_default_constructible<X>::value>::type*);
-#endif // _MSC_VER
 #endif // HAVE_DEFAULT_CONSTRUCTOR_DETECTION_VIA_SFINAE
     // most general sfinae overload, chosen only if everything else fails
     template<typename X>
@@ -187,7 +172,7 @@ public:
 #ifdef OFalign
     // State and content are stored in the same data-array to
     // optimize alignment and so on. Mutable, since the content
-    // itself can be modified even if it cant be (re-)assigned.
+    // itself can be modified even if it can't be (re-)assigned.
     OFdefault_optional_traits() : m_State( OFFalse ) {}
     void destroy() { OFstatic_cast( T*, content() )->~T(); m_State = OFFalse; }
     OFBool state() const { return m_State; }
@@ -266,7 +251,7 @@ struct OFoptional_traits
      */
     <unspecified> is_default_constructible;
 
-    /// <b>Requried</b>: default constructor, must initialize the state to "disengaged".
+    /// <b>Required</b>: default constructor, must initialize the state to "disengaged".
     OFoptional_traits();
 
     /** <b>Required</b>: type constructors, construct the contained object.
@@ -280,7 +265,7 @@ struct OFoptional_traits
     /// <b>Required</b>: type destructor, destroys the underlying object and must set the state to "disengaged".
     void destroy();
 
-    /// <b>Required</b>: state query, must return <i>OFTrue</i> when "engaged" and <i>OFFalse</i> otherwhise.
+    /// <b>Required</b>: state query, must return <i>OFTrue</i> when "engaged" and <i>OFFalse</i> otherwise.
     OFBool state() const;
 
     /// <b>Required</b>: content access, must return a pointer to the contained object.
